There would an aiommy description.
Something about how to use and what is it for.

### Installation ###
pip install aiommy

### TODO: ###
  - test installing
  - refactoring
  - safely managing testing database
  - make test runner for explicit set testing database and database driver

  - license
  - makefile
  - travis
  - separate dev dependencies

  - responses
  - validators
  - views

  - other extensions for peewee
